@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2015 Philip Nienhuis
+## Copyright (C) 2009-2016 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -96,6 +96,26 @@ function [ ods ] = odsopen (filename, rw=0, reqinterface=[])
     error ("No return argument specified!\n usage: ODS = odsopen (ODSfile, [Rw]).\n");
   endif
 
+  if (! (islogical (rw) || isnumeric (rw)))
+      error ("odsopen.m: numerical or logical value expected for arg ## 2 (readwrite)\n")
+  endif
+
+  if (ischar (filename))
+    [pth, fnam, ext] = fileparts (filename);
+    if (isempty (fnam))
+      error ("odsopen.m: no filename or empty filename specified");
+    endif
+    if (rw && ! isempty (pth))
+      apth = make_absolute_filename (pth);
+      if (exist (apth) != 7)
+        error ("odsopen.m: cannot write into non-existent directory:\n'%s'\n", ...
+               apth);
+      endif
+    endif
+  else
+    error ("odsopen.m: filename expected for argument #1");
+  endif
+
   if (! isempty (reqinterface))
     intfmsg = "requested";
     if (! (ischar (reqinterface) || iscell (reqinterface)))
