@@ -26,6 +26,10 @@
 
 function [xls] = __OCT_spsh_close__ (xls)
 
+  if (isfield (xls, "nfilename"))
+    xls.filename = xls.nfilename;
+  endif
+
   ## Check extension and full path to file
   [pth, fname, ext] = fileparts (xls.filename);
   opwd = pwd;
@@ -71,7 +75,6 @@ function [xls] = __OCT_spsh_close__ (xls)
       printf ("odsclose: could not gzip gnumeric contents in %s to %s\n", ...
               xls.workbook, filename);
     endif
-
   endif
 
   ## Delete tmp file and return to work dir
