@@ -1,4 +1,4 @@
-## Copyright (C) 2012,2013 Philip Nienhuis
+## Copyright (C) 2012-2016 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,10 +18,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2012-10-12
-## Updates:
-## 2012-10-24 Style fixes
-## 2013-01-20 Adapted to ML-compatible Java calls
-## 2013-12-01 Copyright string updates
 
 function [ ods, odssupport, lastintf ] = __OTK_spsh_open__ (ods, rw, filename, odssupport)
 
@@ -41,7 +37,7 @@ function [ ods, odssupport, lastintf ] = __OTK_spsh_open__ (ods, rw, filename, o
           javaMethod ("getApplicationVersion", "org.odftoolkit.odfdom.Version");
       end_try_catch
       ## For odfdom-incubator (= 0.8.8+), strip extra info
-      odfvsn = regexp (odfvsn, '\d\.\d\.\d', "match"){1};
+      odfvsn = regexp (odfvsn, '\d\.\d\.\d+', "match"){1};
     endif
 
     odftk = "org.odftoolkit.odfdom.doc";
