@@ -1,4 +1,4 @@
-## Copyright (C) 2012,2013 Philip Nienhuis
+## Copyright (C) 2012-2016 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,31 +18,30 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2012-10-12
-## Updates:
-## 2012-10-24 Style fixes
-## 2013-01-20 Adapted to ML-compatible Java calls
-## 2013-12-06 Updated copyright strings
 
 function [ xls ] = __POI_spsh_close__ (xls)
 
-    if (xls.changed > 0 && xls.changed < 3)
-      if (isfield (xls, "nfilename"))
-        fname = xls.nfilename;
-      else
-        fname = xls.filename;
-      endif
-      try
-        xlsout = javaObject ("java.io.FileOutputStream", fname);
-        bufout = javaObject ("java.io.BufferedOutputStream", xlsout);
-##      if (xls.changed == 2); printf ("Saving file %s...\n", fname); endif
-        xls.workbook.write (bufout);
-        bufout.flush ();
-        bufout.close ();
-        xlsout.close ();
-        xls.changed = 0;
-      catch
-##        xlsout.close ();
-      end_try_catch
+  # Tric to detect xlsout as a Java object
+  xlsout = 1.5;
+  if (xls.changed > 0 && xls.changed < 3)
+    if (isfield (xls, "nfilename"))
+      fname = xls.nfilename;
+    else
+      fname = xls.filename;
     endif
+    try
+      xlsout = javaObject ("java.io.FileOutputStream", fname);
+      bufout = javaObject ("java.io.BufferedOutputStream", xlsout);
+      xls.workbook.write (bufout);
+      bufout.flush ();
+      bufout.close ();
+      xlsout.close ();
+      xls.changed = 0;
+    catch
+      if (! strcmp (class (xlsout), "double"))
+        xlsout.close ();
+      endif
+    end_try_catch
+  endif
 
 endfunction
