@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2015 Philip Nienhuis
+## Copyright (C) 2009-2016 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -61,7 +61,7 @@
 ## Author: Philip Nienhuis <prnienhuis at users.sf.net>
 ## Created: 2009-11-29
 
-function [ xls ] = xlsclose (xls, varargs)
+function [ xls ] = xlsclose (xls, varargin)
 
   if (isempty (xls))
     warning ("xlsclose: file pointer struct was already closed\n");
@@ -71,7 +71,7 @@ function [ xls ] = xlsclose (xls, varargs)
   force = 0;
 
   if (nargin > 1)
-    for ii=2:nargin
+    for ii=1:nargin-1
       if (strcmpi (varargin{ii}, "force"))
         ## Close .xls anyway even if write errors occur
         force = 1;
@@ -83,10 +83,10 @@ function [ xls ] = xlsclose (xls, varargs)
           warning ("xlsclose: file %s wasn't changed, new filename ignored.\n", xls.filename);
         elseif (strcmp (xls.xtype, "JXL"))
           error ("xlsclose: JXL doesn't support changing filename, new filename ignored.\n");
-        elseif (! ((strcmp (xls.xtype, "COM") || strcmp (xls.xtype, "UNO")) ... 
-                && isempty (strfind ( lower (filename), ".xls"))))
+        elseif (isempty (strfind ( lower (varargin{ii}), ".xls")) && ...
+                (! (strcmp (xls.xtype, "COM") || strcmp (xls.xtype, "UNO"))))
           # Excel/ActiveX && OOo (UNO bridge) will write any valid filetype; POI/JXL/OXS need .xls[x]
-          error ("xlsclose: .xls or .xlsx suffix lacking in filename %s\n", filename);
+          error ("xlsclose: .xls or .xlsx suffix lacking in filename %s\n", varargin{ii});
         else
           ## For multi-user environments, uncomment below AND relevant stanza in xlsopen
           ## In case of COM, be sure to first close the open workbook
@@ -96,7 +96,7 @@ function [ xls ] = xlsclose (xls, varargs)
           ##   xls.app.Application.DisplayAlerts = 0;
           ##endif
           ## Preprocessing / -checking ready. Assign filename arg to file ptr struct
-          xls.nfilename = filename;
+          xls.nfilename = varargin{ii};
         endif
       endif
     endfor
