@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2015 Philip Nienhuis
+## Copyright (C) 2009-2016 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -63,6 +63,9 @@
 ## If @var{arr} is smaller than the @var{range} allows, it is placed
 ## in the top left rectangle of @var{range} and remaining cell values
 ## outside the rectangle will be retained.
+## If the third argument is a sheet name and @var{range} is specified as
+## just one cell, it is taken as the topleft cell and the bottomright
+## cell range address is determinded form the data.
 ##
 ## If @var{range} contains merged cells, only the elements of @var{arr}
 ## corresponding to the top or left Excel cells of those merged cells
@@ -133,9 +136,9 @@ function [ rstatus ] = xlswrite (filename, arr, arg3, arg4, arg5)
     ## Assume first worksheet and full worksheet starting at A1
     wsh = 1;
     if (strcmpi (filename(end-4:end-1), ".xls"))
-      crange = "A1:XFD1048576";   ## OOXML has ridiculously large limits 
+      crange = "A1:XFD1048576";     ## OOXML has ridiculously large limits 
     else
-      crange = "A1:IV65536";      ## Regular xls limits
+      crange = "A1:IV65536";        ## Regular xls limits
     endif
   elseif (nargin == 3)
     ## Find out whether 3rd argument = worksheet or range
@@ -143,9 +146,9 @@ function [ rstatus ] = xlswrite (filename, arr, arg3, arg4, arg5)
       ## Apparently a worksheet specified
       wsh = arg3;
       if (strcmpi (filename(end-4:end-1), ".xls"))
-        crange = "A1:XFD1048576"; ## OOXML has ridiculously large limits 
+        crange = "A1:XFD1048576";   ## OOXML has ridiculously large limits 
       else
-        crange = "A1:IV65536";    ## Regular xls limits
+        crange = "A1:IV65536";      ## Regular xls limits
       endif
     else
       ## Range specified
@@ -155,6 +158,7 @@ function [ rstatus ] = xlswrite (filename, arr, arg3, arg4, arg5)
   elseif (nargin >= 4)
     wsh = arg3;
     crange = arg4;
+    r_extnd = (isempty (strfind (crange, ":")) && nargin >= 4);
   endif
   if (nargin == 5)
     reqintf = arg5;
@@ -164,11 +168,16 @@ function [ rstatus ] = xlswrite (filename, arr, arg3, arg4, arg5)
   if (isempty (wsh))
     wsh = 1;
   endif
-  if (isempty (crange))
-    if (strcmpi (filename(end-4:end-1), ".xls"))
-      crange = "A1:XFD1048576"; ## OOXML has ridiculously large limits 
+  if (isempty (crange) || r_extnd)
+    if (r_extnd)
+      tlcl = crange;
     else
-      crange = "A1:IV65536";    ## Regular xls limits
+      tlcl = "A1";
+    endif
+    if (strcmpi (filename(end-4:end-1), ".xls"))
+      crange = [tlcl ":XFD1048576"]; ## OOXML has ridiculously large limits 
+    else
+      crange = [tlcl ":IV65536"];    ## Regular xls limits
     endif
   endif
   
@@ -181,7 +190,7 @@ function [ rstatus ] = xlswrite (filename, arr, arg3, arg4, arg5)
     # Array too big; truncate
     nr = min (nrows, nr);
     nc = min (ncols, nc);
-    warning ("xlswrite - array truncated to %d by %d to fit in range %s", ...
+    warning ("xlswrite - array truncated to %d by %d to fit in range %s\n", ...
              nrows, ncols, crange);
     ## Adapt crange
     crange = [ calccelladdress(trow, lcol) ":" ...
