@@ -1,4 +1,5 @@
 // Copyright (C) 2004 Laurent Mazet <mazet@crm.mot.com>
+// Copyright (C) 2016 Philip Nienhuis <prnienhuis@users.sf.net>  
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -49,6 +50,7 @@
 */
 
 #include <fstream>
+#include <stdint.h>
 
 #include <octave/oct.h>
 #include <octave/Cell.h>
@@ -112,8 +114,8 @@ DEFUN_DLD (cell2csv, args, nargout,
       if (c(i, j).is_real_scalar()) {
 
         /* Output real value */
-        char tmp[20];
-        sprintf(tmp, "%g", c(i, j).double_value());
+        char tmp[30];
+        sprintf(tmp, "%.15g", c(i, j).double_value());
         word += tmp;
       }
 
